#include "orbsvcs/Notify/Event_Persistence_Factory.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Notify::Event_Persistence_Factory::~Event_Persistence_Factory ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
